==> cpputest_3.4.orig.tar.gz: cpputest-3.4/examples/AllTests/PrinterTest.cpp <==
/*
 * Copyright (c) 2007, Michael Feathers, James Grenning and Bas Vodde
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE EARLIER MENTIONED AUTHORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL <copyright holder> BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "CppUTest/TestHarness.h"
#include "Printer.h"
#include "MockPrinter.h"

TEST_GROUP(Printer)
{ Printer* printer;
MockPrinter* mockPrinter;

void setup()
{
	mockPrinter = new MockPrinter();
	printer = mockPrinter;
}
void teardown()
{
	delete printer;
}
};

TEST(Printer, PrintConstCharStar)
{
	printer->Print("hello");
	printer->Print("hello\n");
	CHECK_EQUAL("hellohello\n", mockPrinter->getOutput());
}

TEST(Printer, PrintLong)
{
	printer->Print(1234);
	CHECK_EQUAL("1234", mockPrinter->getOutput());
}

TEST(Printer, StreamOperators)
{
	*printer << "n=" << 1234;
	CHECK_EQUAL("n=1234", mockPrinter->getOutput());
}

==> cpputest_4.0.orig.tar.gz: cpputest-4.0/examples/AllTests/PrinterTest.cpp <==
/*
 * Copyright (c) 2007, Michael Feathers, James Grenning and Bas Vodde
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE EARLIER MENTIONED AUTHORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL <copyright holder> BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "CppUTest/TestHarness.h"
#include "Printer.h"
#include "MockPrinter.h"

TEST_GROUP(Printer)
{ Printer* printer;
MockPrinter* mockPrinter;

void setup()
{
    mockPrinter = new MockPrinter();
    printer = mockPrinter;
}
void teardown()
{
    delete printer;
}
};

TEST(Printer, PrintConstCharStar)
{
    printer->Print("hello");
    printer->Print("hello\n");
    const char* expected = "hellohello\n";
    CHECK_EQUAL(expected, mockPrinter->getOutput());
}

TEST(Printer, PrintLong)
{
    printer->Print(1234);
    const char* expected = "1234";
    CHECK_EQUAL(expected, mockPrinter->getOutput());
}

TEST(Printer, StreamOperators)
{
    *printer << "n=" << 1234;
    const char* expected = "n=1234";
    CHECK_EQUAL(expected, mockPrinter->getOutput());
}
